==> baison-base-facade-mengjie-1.0-20250808.070038-9-sources.jar: com/bizvane/baisonBase/facade/rpc/MjShuyunMemberServiceRpc.java <==
package com.bizvane.baisonBase.facade.rpc;


import com.bizvane.baisonBase.facade.models.mj.*;
import com.bizvane.connectorservice.entity.common.*;
import com.bizvane.couponfacade.models.vo.CouponEntityAndDefinitionVO;
import com.bizvane.couponfacade.models.vo.CouponListByMemberCodeRequestVO;
import com.bizvane.members.facade.models.IntegralRecordModel;
import com.bizvane.members.facade.vo.IntegralRecordVo;
import com.bizvane.members.facade.vo.MemberCouponExpireRequestVo;
import com.bizvane.utils.responseinfo.PageInfo;
import com.bizvane.utils.responseinfo.ResponseData;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * 梦洁会员接口
 * */
@FeignClient(value = "${feign.client.baison.name}", path = "${feign.client.baison.path}/mjShuyunMember")
public interface MjShuyunMemberServiceRpc {

    /**
     * 查询会员
     * */
    @RequestMapping(value ="queryMemberInfo",method = RequestMethod.POST)
    ResponseData<MjShuyunMemberQueryResponseVO> queryMemberInfo(@RequestParam("brandCode") String brandCode, @RequestParam("erpId") String erpId);

    /**
     * 会员注册修改
     * */
    @RequestMapping(value ="register",method = RequestMethod.POST)
    ResponseData<MjShuyunMemberOpenCardResponseVO> register(@RequestBody MjShuyunMemberOpenCardRequestVO requestVo);

    @RequestMapping(value ="mbrUpdate",method = RequestMethod.POST)
    ResponseData<Object> mbrUpdate(@RequestBody MemberOpenCardRequestVO requestVo);

    @RequestMapping(value ="getShuyunMbrLevel",method = RequestMethod.POST)
    ResponseData<String> getShuyunMbrLevel(@RequestParam("brandCode") String brandCode, @RequestParam("erpId") String erpId);

    @RequestMapping(value ="getShuyunMbrIntegral",method = RequestMethod.POST)
    ResponseData<Integer> getShuyunMbrIntegral(@RequestParam("brandCode") String brandCode, @RequestParam("erpId") String erpId);

    /**
     * 会员积分调整
     * */
    @RequestMapping(value ="adjustIntegral",method = RequestMethod.POST)
    ResponseData<IntegralAdjustResponseVO> adjustIntegral(@RequestBody MjShuyunIntegralAdjustRequestVO requestVo);

    @RequestMapping(value = "listIntegralRecord", method = RequestMethod.POST)
    ResponseData<PageInfo<IntegralRecordModel>> listIntegralRecord(@RequestBody IntegralRecordVo integralRecordVo);

    @RequestMapping(value ="listCouponExpireMember",method = RequestMethod.POST)
    ResponseData<PageInfo<MjShuyunCouponExpireMemberResponseVO>> listCouponExpireMember(@RequestBody MemberCouponExpireRequestVo requestVO);

    @RequestMapping(value ="getShuyunMbrLevel",method = RequestMethod.POST)
    ResponseData<Object> mbrLabelAdd(@RequestBody MjShuyunMbrLabelAddRequestVO requestVO);;

    @RequestMapping(value ="getShuyunMbrLevel",method = RequestMethod.POST)
    ResponseData<Object> mbrLabelDelete(@RequestBody MjShuyunMbrLabelDeleteRequestVO requestVO);;

    @RequestMapping(value ="getShuyunMbrLevel",method = RequestMethod.POST)
    ResponseData<MjShuyunMbrGuideQueryResp> mbrGuideUpdateQuery(@RequestBody MjShuyunMbrGuideUpdateQueryReq requestVO);

    @RequestMapping(value ="getShuyunMbrLevel",method = RequestMethod.POST)
    ResponseData<Object> mbrGuideUpdateConfirm(@RequestBody MjShuyunMbrGuideUpdateConfirmReq requestVO);

}

==> baison-base-facade-mengjie-1.0-20250811.112932-12-sources.jar: com/bizvane/baisonBase/facade/rpc/MjShuyunMemberServiceRpc.java <==
package com.bizvane.baisonBase.facade.rpc;


import com.bizvane.baisonBase.facade.models.mj.*;
import com.bizvane.connectorservice.entity.Result;
import com.bizvane.connectorservice.entity.common.*;
import com.bizvane.couponfacade.models.vo.CouponEntityAndDefinitionVO;
import com.bizvane.couponfacade.models.vo.CouponListByMemberCodeRequestVO;
import com.bizvane.members.facade.models.IntegralRecordModel;
import com.bizvane.members.facade.vo.IntegralRecordVo;
import com.bizvane.members.facade.vo.MemberCouponExpireRequestVo;
import com.bizvane.utils.responseinfo.PageInfo;
import com.bizvane.utils.responseinfo.ResponseData;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * 梦洁会员接口
 * */
@FeignClient(value = "${feign.client.baison.name}", path = "${feign.client.baison.path}/mjShuyunMember")
public interface MjShuyunMemberServiceRpc {

    /**
     * 查询会员
     * */
    @RequestMapping(value ="queryMemberInfo",method = RequestMethod.POST)
    ResponseData<MjShuyunMemberQueryResponseVO> queryMemberInfo(@RequestParam("brandCode") String brandCode, @RequestParam("erpId") String erpId);

    /**
     * 会员注册修改
     * */
    @RequestMapping(value ="register",method = RequestMethod.POST)
    Result<MemberOpenCardResponseVO> register(@RequestBody MemberOpenCardRequestVO requestVo);

    @RequestMapping(value ="mbrUpdate",method = RequestMethod.POST)
    Result<Object> mbrUpdate(@RequestBody MemberOpenCardRequestVO requestVo);

    @RequestMapping(value ="getShuyunMbrLevel",method = RequestMethod.POST)
    ResponseData<String> getShuyunMbrLevel(@RequestParam("brandCode") String brandCode, @RequestParam("erpId") String erpId);

    @RequestMapping(value ="getShuyunMbrIntegral",method = RequestMethod.POST)
    ResponseData<Integer> getShuyunMbrIntegral(@RequestParam("brandCode") String brandCode, @RequestParam("erpId") String erpId);

    /**
     * 会员积分调整
     * */
    @RequestMapping(value ="adjustIntegral",method = RequestMethod.POST)
    ResponseData<IntegralAdjustResponseVO> adjustIntegral(@RequestBody MjShuyunIntegralAdjustRequestVO requestVo);

    @RequestMapping(value = "listIntegralRecord", method = RequestMethod.POST)
    ResponseData<PageInfo<IntegralRecordModel>> listIntegralRecord(@RequestBody IntegralRecordVo integralRecordVo);

    @RequestMapping(value ="listCouponExpireMember",method = RequestMethod.POST)
    ResponseData<PageInfo<MjShuyunCouponExpireMemberResponseVO>> listCouponExpireMember(@RequestBody MemberCouponExpireRequestVo requestVO);

    @RequestMapping(value ="getShuyunMbrLevel",method = RequestMethod.POST)
    ResponseData<Object> mbrLabelAdd(@RequestBody MjShuyunMbrLabelAddRequestVO requestVO);;

    @RequestMapping(value ="getShuyunMbrLevel",method = RequestMethod.POST)
    ResponseData<Object> mbrLabelDelete(@RequestBody MjShuyunMbrLabelDeleteRequestVO requestVO);;

    @RequestMapping(value ="getShuyunMbrLevel",method = RequestMethod.POST)
    ResponseData<MjShuyunMbrGuideQueryResp> mbrGuideUpdateQuery(@RequestBody MjShuyunMbrGuideUpdateQueryReq requestVO);

    @RequestMapping(value ="getShuyunMbrLevel",method = RequestMethod.POST)
    ResponseData<Object> mbrGuideUpdateConfirm(@RequestBody MjShuyunMbrGuideUpdateConfirmReq requestVO);

}
